@@ -247,7 +247,7 @@ read_zone_data(udb_base* udb, namedb_type* db, region_type* dname_region,
 /** create a zone */
 zone_type*
 namedb_zone_create(namedb_type* db, const dname_type* dname,
-	zone_options_t* zo)
+	struct zone_options* zo)
 {
 	zone_type* zone = (zone_type *) region_alloc(db->region,
 		sizeof(zone_type));
@@ -321,12 +321,12 @@ namedb_zone_delete(namedb_type* db, zone_type* zone)
 #ifdef HAVE_MMAP
 /** read a zone */
 static void
-read_zone(udb_base* udb, namedb_type* db, nsd_options_t* opt,
+read_zone(udb_base* udb, namedb_type* db, struct nsd_options* opt,
 	region_type* dname_region, udb_ptr* z)
 {
 	/* construct dname */
 	const dname_type* dname = dname_make(dname_region, ZONE(z)->name, 0);
-	zone_options_t* zo = dname?zone_options_find(opt, dname):NULL;
+	struct zone_options* zo = dname?zone_options_find(opt, dname):NULL;
 	zone_type* zone;
 	if(!dname) return;
 	if(!zo) {
@@ -353,7 +353,7 @@ read_zone(udb_base* udb, namedb_type* db, nsd_options_t* opt,
 #ifdef HAVE_MMAP
 /** read zones from nsd.db */
 static void
-read_zones(udb_base* udb, namedb_type* db, nsd_options_t* opt,
+read_zones(udb_base* udb, namedb_type* db, struct nsd_options* opt,
 	region_type* dname_region)
 {
 	udb_ptr ztree, n, z;
@@ -378,7 +378,7 @@ read_zones(udb_base* udb, namedb_type* db, nsd_options_t* opt,
 /** try to read the udb file or fail */
 static int
 try_read_udb(namedb_type* db, int fd, const char* filename,
-	nsd_options_t* opt)
+	struct nsd_options* opt)
 {
 	/*
 	 * Temporary region used while loading domain names from the
@@ -414,7 +414,7 @@ try_read_udb(namedb_type* db, int fd, const char* filename,
 #endif /* HAVE_MMAP */
 
 struct namedb *
-namedb_open (const char* filename, nsd_options_t* opt)
+namedb_open (const char* filename, struct nsd_options* opt)
 {
 	namedb_type* db;
 
@@ -653,7 +653,7 @@ namedb_read_zonefile(struct nsd* nsd, struct zone* zone, udb_base* taskudb,
 }
 
 void namedb_check_zonefile(struct nsd* nsd, udb_base* taskudb,
-	udb_ptr* last_task, zone_options_t* zopt)
+	udb_ptr* last_task, struct zone_options* zopt)
 {
 	zone_type* zone;
 	const dname_type* dname = (const dname_type*)zopt->node.key;
@@ -665,12 +665,12 @@ void namedb_check_zonefile(struct nsd* nsd, udb_base* taskudb,
 	namedb_read_zonefile(nsd, zone, taskudb, last_task);
 }
 
-void namedb_check_zonefiles(struct nsd* nsd, nsd_options_t* opt,
+void namedb_check_zonefiles(struct nsd* nsd, struct nsd_options* opt,
 	udb_base* taskudb, udb_ptr* last_task)
 {
-	zone_options_t* zo;
+	struct zone_options* zo;
 	/* check all zones in opt, create if not exist in main db */
-	RBTREE_FOR(zo, zone_options_t*, opt->zone_options) {
+	RBTREE_FOR(zo, struct zone_options*, opt->zone_options) {
 		namedb_check_zonefile(nsd, taskudb, last_task, zo);
 		if(nsd->signal_hint_shutdown) break;
 	}
