@@ -106,7 +106,7 @@ static void ssl_err(const char* s)
 
 /** setup SSL context */
 static SSL_CTX*
-setup_ctx(nsd_options_t* cfg)
+setup_ctx(struct nsd_options* cfg)
 {
 	char* s_cert, *c_key, *c_cert;
 	SSL_CTX* ctx;
@@ -144,7 +144,7 @@ setup_ctx(nsd_options_t* cfg)
 
 /** contact the server with TCP connect */
 static int
-contact_server(const char* svr, nsd_options_t* cfg, int statuscmd)
+contact_server(const char* svr, struct nsd_options* cfg, int statuscmd)
 {
 #ifdef INET6
 	struct sockaddr_storage addr;
@@ -156,9 +156,13 @@ contact_server(const char* svr, nsd_options_t* cfg, int statuscmd)
 	int port = cfg->control_port;
 	/* use svr or a config entry */
 	if(!svr) {
-		if(cfg->control_interface)
+		if(cfg->control_interface) {
 			svr = cfg->control_interface->address;
-		else	svr = "127.0.0.1";
+		} else if(cfg->do_ip4) {
+			svr = "127.0.0.1";
+		} else {
+			svr = "::1";
+		}
 		/* config 0 addr (everything), means ask localhost */
 		if(strcmp(svr, "0.0.0.0") == 0)
 			svr = "127.0.0.1";
@@ -317,7 +321,7 @@ go_cmd(SSL* ssl, int argc, char* argv[])
 static int
 go(const char* cfgfile, char* svr, int argc, char* argv[])
 {
-	nsd_options_t* opt;
+	struct nsd_options* opt;
 	int fd, ret;
 	SSL_CTX* ctx;
 	SSL* ssl;
