@@ -139,7 +139,7 @@ print_zone_mem(struct zone_mem* z)
 }
 
 static void
-account_total(nsd_options_t* opt, struct tot_mem* t)
+account_total(struct nsd_options* opt, struct tot_mem* t)
 {
 	t->opt_data = region_get_mem(opt->region);
 	t->opt_unused = region_get_mem_unused(opt->region);
@@ -192,8 +192,8 @@ add_mem(struct tot_mem* t, struct zone_mem* z)
 }
 
 static void
-check_zone_mem(const char* tf, const char* df, zone_options_t* zo,
-	nsd_options_t* opt, struct tot_mem* totmem)
+check_zone_mem(const char* tf, const char* df, struct zone_options* zo,
+	struct nsd_options* opt, struct tot_mem* totmem)
 {
 	struct nsd nsd;
 	struct namedb* db;
@@ -234,10 +234,10 @@ check_zone_mem(const char* tf, const char* df, zone_options_t* zo,
 }
 
 static void
-check_mem(nsd_options_t* opt)
+check_mem(struct nsd_options* opt)
 {
 	struct tot_mem totmem;
-	zone_options_t* zo;
+	struct zone_options* zo;
 	char tf[512];
 	char df[512];
 	memset(&totmem, 0, sizeof(totmem));
@@ -247,7 +247,7 @@ check_mem(nsd_options_t* opt)
 	else snprintf(df, sizeof(df), "./nsd-mem-db-%u.db", (unsigned)getpid());
 
 	/* read all zones and account memory */
-	RBTREE_FOR(zo, zone_options_t*, opt->zone_options) {
+	RBTREE_FOR(zo, struct zone_options*, opt->zone_options) {
 		check_zone_mem(tf, df, zo, opt, &totmem);
 	}
 
