@@ -72,5 +72,7 @@ enum rrl_type rrlstr2type(const char* s);
 /** for unit test, update rrl bucket; return rate */
 uint32_t rrl_update(query_type* query, uint32_t hash, uint64_t source,
 	uint16_t flags, int32_t now, uint32_t lm);
+/** set the rate limit counters, pass variables in qps */
+void rrl_set_limit(size_t lm, size_t wlm, size_t sm);
 
 #endif /* RRL_H */
