@@ -42,7 +42,7 @@
 		 * was lost, and need waitpid to remove their process entry. */
 
 /* the daemon state */
-xfrd_state_t* xfrd = 0;
+xfrd_state_type* xfrd = 0;
 
 /* main xfrd loop */
 static void xfrd_main(void);
@@ -56,16 +56,18 @@ static void xfrd_init_zones(void);
 static void xfrd_receive_soa(int socket, int shortsoa);
 
 /* handle incoming notification message. soa can be NULL. true if transfer needed. */
-static int xfrd_handle_incoming_notify(xfrd_zone_t* zone, xfrd_soa_t* soa);
+static int xfrd_handle_incoming_notify(xfrd_zone_type* zone,
+	xfrd_soa_type* soa);
 
 /* call with buffer just after the soa dname. returns 0 on error. */
-static int xfrd_parse_soa_info(buffer_type* packet, xfrd_soa_t* soa);
+static int xfrd_parse_soa_info(buffer_type* packet, xfrd_soa_type* soa);
 /* set the zone state to a new state (takes care of expiry messages) */
-static void xfrd_set_zone_state(xfrd_zone_t* zone, enum xfrd_zone_state new_zone_state);
+static void xfrd_set_zone_state(xfrd_zone_type* zone,
+	enum xfrd_zone_state new_zone_state);
 /* set timer for retry amount (depends on zone_state) */
-static void xfrd_set_timer_retry(xfrd_zone_t* zone);
+static void xfrd_set_timer_retry(xfrd_zone_type* zone);
 /* set timer for refresh timeout (depends on zone_state) */
-static void xfrd_set_timer_refresh(xfrd_zone_t* zone);
+static void xfrd_set_timer_refresh(xfrd_zone_type* zone);
 
 /* set reload timeout */
 static void xfrd_set_reload_timeout(void);
@@ -75,15 +77,15 @@ static void xfrd_handle_reload(int fd, short event, void* arg);
 static void xfrd_handle_child_timer(int fd, short event, void* arg);
 
 /* send ixfr request, returns fd of connection to read on */
-static int xfrd_send_ixfr_request_udp(xfrd_zone_t* zone);
+static int xfrd_send_ixfr_request_udp(xfrd_zone_type* zone);
 /* obtain udp socket slot */
-static void xfrd_udp_obtain(xfrd_zone_t* zone);
+static void xfrd_udp_obtain(xfrd_zone_type* zone);
 
 /* read data via udp */
-static void xfrd_udp_read(xfrd_zone_t* zone);
+static void xfrd_udp_read(xfrd_zone_type* zone);
 
 /* find master by notify number */
-static int find_same_master_notify(xfrd_zone_t* zone, int acl_num_nfy);
+static int find_same_master_notify(xfrd_zone_type* zone, int acl_num_nfy);
 
 /* set the write timer to activate */
 static void xfrd_write_timer_set(void);
@@ -122,8 +124,8 @@ xfrd_init(int socket, struct nsd* nsd, int shortsoa, int reload_active,
 
 	region = region_create_custom(xalloc, free, DEFAULT_CHUNK_SIZE,
 		DEFAULT_LARGE_OBJECT_SIZE, DEFAULT_INITIAL_CLEANUP_SIZE, 1);
-	xfrd = (xfrd_state_t*)region_alloc(region, sizeof(xfrd_state_t));
-	memset(xfrd, 0, sizeof(xfrd_state_t));
+	xfrd = (xfrd_state_type*)region_alloc(region, sizeof(xfrd_state_type));
+	memset(xfrd, 0, sizeof(xfrd_state_type));
 	xfrd->region = region;
 	xfrd->xfrd_start_time = time(0);
 	xfrd->event_base = nsd_child_event_base();
@@ -221,7 +223,7 @@ xfrd_init(int socket, struct nsd* nsd, int shortsoa, int reload_active,
 static void
 xfrd_process_activated(void)
 {
-	xfrd_zone_t* zone;
+	xfrd_zone_type* zone;
 	while((zone = xfrd->activated_first)) {
 		DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd zone %s activation",
 			zone->apex_str));
@@ -314,7 +316,7 @@ xfrd_main(void)
 static void
 xfrd_shutdown()
 {
-	xfrd_zone_t* zone;
+	xfrd_zone_type* zone;
 
 	DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd shutdown"));
 	event_del(&xfrd->ipc_handler);
@@ -336,7 +338,7 @@ xfrd_shutdown()
 	daemon_remote_close(xfrd->nsd->rc); /* close sockets of rc */
 #endif
 	/* close sockets */
-	RBTREE_FOR(zone, xfrd_zone_t*, xfrd->zones)
+	RBTREE_FOR(zone, xfrd_zone_type*, xfrd->zones)
 	{
 		if(zone->event_added) {
 			event_del(&zone->zone_handler);
@@ -369,7 +371,7 @@ xfrd_shutdown()
 	 * to clean them out */
 
 	/* unlink xfr files for running transfers */
-	RBTREE_FOR(zone, xfrd_zone_t*, xfrd->zones)
+	RBTREE_FOR(zone, xfrd_zone_type*, xfrd->zones)
 	{
 		if(zone->msg_seq_nr)
 			xfrd_unlink_xfrfile(xfrd->nsd, zone->xfrfilenumber);
@@ -400,11 +402,12 @@ xfrd_clean_pending_tasks(struct nsd* nsd, udb_base* u)
 }
 
 void
-xfrd_init_slave_zone(xfrd_state_t* xfrd, zone_options_t* zone_opt)
+xfrd_init_slave_zone(xfrd_state_type* xfrd, struct zone_options* zone_opt)
 {
-	xfrd_zone_t *xzone;
-	xzone = (xfrd_zone_t*)region_alloc(xfrd->region, sizeof(xfrd_zone_t));
-	memset(xzone, 0, sizeof(xfrd_zone_t));
+	xfrd_zone_type *xzone;
+	xzone = (xfrd_zone_type*)region_alloc(xfrd->region,
+		sizeof(xfrd_zone_type));
+	memset(xzone, 0, sizeof(xfrd_zone_type));
 	xzone->apex = zone_opt->node.key;
 	xzone->apex_str = zone_opt->name;
 	xzone->state = xfrd_zone_refreshing;
@@ -443,13 +446,13 @@ xfrd_init_slave_zone(xfrd_state_t* xfrd, zone_options_t* zone_opt)
 	xfrd_set_refresh_now(xzone);
 
 	xzone->node.key = xzone->apex;
-	rbtree_insert(xfrd->zones, (rbnode_t*)xzone);
+	rbtree_insert(xfrd->zones, (rbnode_type*)xzone);
 }
 
 static void
 xfrd_init_zones()
 {
-	zone_options_t *zone_opt;
+	struct zone_options *zone_opt;
 	assert(xfrd->zones == 0);
 
 	xfrd->zones = rbtree_create(xfrd->region,
@@ -457,7 +460,7 @@ xfrd_init_zones()
 	xfrd->notify_zones = rbtree_create(xfrd->region,
 		(int (*)(const void *, const void *)) dname_compare);
 
-	RBTREE_FOR(zone_opt, zone_options_t*, xfrd->nsd->options->zone_options)
+	RBTREE_FOR(zone_opt, struct zone_options*, xfrd->nsd->options->zone_options)
 	{
 		DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd: adding %s zone",
 			zone_opt->name));
@@ -478,12 +481,12 @@ xfrd_init_zones()
 static void
 xfrd_process_soa_info_task(struct task_list_d* task)
 {
-	xfrd_soa_t soa;
-	xfrd_soa_t* soa_ptr = &soa;
-	xfrd_zone_t* zone;
+	xfrd_soa_type soa;
+	xfrd_soa_type* soa_ptr = &soa;
+	xfrd_zone_type* zone;
 	DEBUG(DEBUG_IPC,1, (LOG_INFO, "xfrd: process SOAINFO %s",
 		dname_to_string(task->zname, 0)));
-	zone = (xfrd_zone_t*)rbtree_search(xfrd->zones, task->zname);
+	zone = (xfrd_zone_type*)rbtree_search(xfrd->zones, task->zname);
 	if(task->size <= sizeof(struct task_list_d)+dname_total_size(
 		task->zname)+sizeof(uint32_t)*6 + sizeof(uint8_t)*2) {
 		/* NSD has zone without any info */
@@ -540,12 +543,12 @@ xfrd_receive_soa(int socket, int shortsoa)
 	sig_atomic_t cmd;
 	struct udb_base* xtask = xfrd->nsd->task[xfrd->nsd->mytask];
 	udb_ptr last_task, t;
-	xfrd_zone_t* zone;
+	xfrd_zone_type* zone;
 
 	if(!shortsoa) {
 		/* put all expired zones into mytask */
 		udb_ptr_init(&last_task, xtask);
-		RBTREE_FOR(zone, xfrd_zone_t*, xfrd->zones) {
+		RBTREE_FOR(zone, xfrd_zone_type*, xfrd->zones) {
 			if(zone->state == xfrd_zone_expired) {
 				task_new_expire(xtask, &last_task, zone->apex, 1);
 			}
@@ -605,7 +608,7 @@ xfrd_receive_soa(int socket, int shortsoa)
 		/* for shortsoa version, do expire later */
 		/* if expire notifications, put in my task and
 		 * schedule a reload to make sure they are processed */
-		RBTREE_FOR(zone, xfrd_zone_t*, xfrd->zones) {
+		RBTREE_FOR(zone, xfrd_zone_type*, xfrd->zones) {
 			if(zone->state == xfrd_zone_expired) {
 				xfrd_send_expire_notification(zone);
 			}
@@ -621,7 +624,7 @@ xfrd_reopen_logfile(void)
 }
 
 void
-xfrd_deactivate_zone(xfrd_zone_t* z)
+xfrd_deactivate_zone(xfrd_zone_type* z)
 {
 	if(z->is_activated) {
 		/* delete from activated list */
@@ -635,9 +638,9 @@ xfrd_deactivate_zone(xfrd_zone_t* z)
 }
 
 void
-xfrd_del_slave_zone(xfrd_state_t* xfrd, const dname_type* dname)
+xfrd_del_slave_zone(xfrd_state_type* xfrd, const dname_type* dname)
 {
-	xfrd_zone_t* z = (xfrd_zone_t*)rbtree_delete(xfrd->zones, dname);
+	xfrd_zone_type* z = (xfrd_zone_type*)rbtree_delete(xfrd->zones, dname);
 	if(!z) return;
 	
 	/* io */
@@ -691,7 +694,7 @@ xfrd_free_namedb(struct nsd* nsd)
 }
 
 static void
-xfrd_set_timer_refresh(xfrd_zone_t* zone)
+xfrd_set_timer_refresh(xfrd_zone_type* zone)
 {
 	time_t set_refresh;
 	time_t set_expire;
@@ -722,7 +725,7 @@ xfrd_set_timer_refresh(xfrd_zone_t* zone)
 }
 
 static void
-xfrd_set_timer_retry(xfrd_zone_t* zone)
+xfrd_set_timer_retry(xfrd_zone_type* zone)
 {
 	time_t set_retry;
 	int mult;
@@ -782,7 +785,7 @@ xfrd_set_timer_retry(xfrd_zone_t* zone)
 void
 xfrd_handle_zone(int ATTR_UNUSED(fd), short event, void* arg)
 {
-	xfrd_zone_t* zone = (xfrd_zone_t*)arg;
+	xfrd_zone_type* zone = (xfrd_zone_type*)arg;
 
 	if(zone->tcp_conn != -1) {
 		if(event == 0) /* activated, but already in TCP, nothing to do*/
@@ -846,7 +849,7 @@ xfrd_handle_zone(int ATTR_UNUSED(fd), short event, void* arg)
 }
 
 void
-xfrd_make_request(xfrd_zone_t* zone)
+xfrd_make_request(xfrd_zone_type* zone)
 {
 	if(zone->next_master != -1) {
 		/* we are told to use this next master */
@@ -954,7 +957,7 @@ xfrd_make_request(xfrd_zone_t* zone)
 }
 
 static void
-xfrd_udp_obtain(xfrd_zone_t* zone)
+xfrd_udp_obtain(xfrd_zone_type* zone)
 {
 	assert(zone->udp_waiting == 0);
 	if(zone->tcp_conn != -1) {
@@ -1005,7 +1008,7 @@ xfrd_time()
 }
 
 void
-xfrd_copy_soa(xfrd_soa_t* soa, rr_type* rr)
+xfrd_copy_soa(xfrd_soa_type* soa, rr_type* rr)
 {
 	const uint8_t* rr_ns_wire = dname_name(domain_dname(rdata_atom_domain(rr->rdatas[0])));
 	uint8_t rr_ns_len = domain_dname(rdata_atom_domain(rr->rdatas[0]))->name_size;
@@ -1043,7 +1046,7 @@ xfrd_copy_soa(xfrd_soa_t* soa, rr_type* rr)
 }
 
 static void
-xfrd_set_zone_state(xfrd_zone_t* zone, enum xfrd_zone_state s)
+xfrd_set_zone_state(xfrd_zone_type* zone, enum xfrd_zone_state s)
 {
 	if(s != zone->state) {
 		enum xfrd_zone_state old = zone->state;
@@ -1056,7 +1059,7 @@ xfrd_set_zone_state(xfrd_zone_t* zone, enum xfrd_zone_state s)
 }
 
 void
-xfrd_set_refresh_now(xfrd_zone_t* zone)
+xfrd_set_refresh_now(xfrd_zone_type* zone)
 {
 	DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd zone %s is activated, state %d",
 		zone->apex_str, zone->state));
@@ -1072,7 +1075,7 @@ xfrd_set_refresh_now(xfrd_zone_t* zone)
 }
 
 void
-xfrd_unset_timer(xfrd_zone_t* zone)
+xfrd_unset_timer(xfrd_zone_type* zone)
 {
 	assert(zone->zone_handler.ev_fd == -1);
 	if(zone->event_added)
@@ -1082,7 +1085,7 @@ xfrd_unset_timer(xfrd_zone_t* zone)
 }
 
 void
-xfrd_set_timer(xfrd_zone_t* zone, time_t t)
+xfrd_set_timer(xfrd_zone_type* zone, time_t t)
 {
 	int fd = zone->zone_handler.ev_fd;
 	int fl = ((fd == -1)?EV_TIMEOUT:zone->zone_handler_flags);
@@ -1116,8 +1119,8 @@ xfrd_set_timer(xfrd_zone_t* zone, time_t t)
 }
 
 void
-xfrd_handle_incoming_soa(xfrd_zone_t* zone,
-	xfrd_soa_t* soa, time_t acquired)
+xfrd_handle_incoming_soa(xfrd_zone_type* zone,
+	xfrd_soa_type* soa, time_t acquired)
 {
 	if(soa == NULL) {
 		/* nsd no longer has a zone in memory */
@@ -1199,7 +1202,7 @@ xfrd_handle_incoming_soa(xfrd_zone_t* zone,
 }
 
 void
-xfrd_send_expire_notification(xfrd_zone_t* zone)
+xfrd_send_expire_notification(xfrd_zone_type* zone)
 {
 	task_new_expire(xfrd->nsd->task[xfrd->nsd->mytask], xfrd->last_task,
 		zone->apex, zone->state == xfrd_zone_expired);
@@ -1225,7 +1228,7 @@ xfrd_udp_read_packet(buffer_type* packet, int fd)
 }
 
 void
-xfrd_udp_release(xfrd_zone_t* zone)
+xfrd_udp_release(xfrd_zone_type* zone)
 {
 	assert(zone->udp_waiting == 0);
 	if(zone->event_added)
@@ -1241,7 +1244,7 @@ xfrd_udp_release(xfrd_zone_t* zone)
 	{
 		while(xfrd->udp_waiting_first) {
 			/* snip off waiting list */
-			xfrd_zone_t* wz = xfrd->udp_waiting_first;
+			xfrd_zone_type* wz = xfrd->udp_waiting_first;
 			assert(wz->udp_waiting);
 			wz->udp_waiting = 0;
 			xfrd->udp_waiting_first = wz->udp_waiting_next;
@@ -1281,7 +1284,7 @@ xfrd_udp_release(xfrd_zone_t* zone)
 
 /** disable ixfr for master */
 void
-xfrd_disable_ixfr(xfrd_zone_t* zone)
+xfrd_disable_ixfr(xfrd_zone_type* zone)
 {
 	if(!(zone->master->ixfr_disabled &&
 		(zone->master->ixfr_disabled + XFRD_NO_IXFR_CACHE) <= time(NULL))) {
@@ -1293,7 +1296,7 @@ xfrd_disable_ixfr(xfrd_zone_t* zone)
 }
 
 static void
-xfrd_udp_read(xfrd_zone_t* zone)
+xfrd_udp_read(xfrd_zone_type* zone)
 {
 	DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd: zone %s read udp data", zone->apex_str));
 	if(!xfrd_udp_read_packet(xfrd->packet, zone->zone_handler.ev_fd)) {
@@ -1355,7 +1358,8 @@ xfrd_udp_read(xfrd_zone_t* zone)
 }
 
 int
-xfrd_send_udp(acl_options_t* acl, buffer_type* packet, acl_options_t* ifc)
+xfrd_send_udp(struct acl_options* acl, buffer_type* packet,
+	struct acl_options* ifc)
 {
 #ifdef INET6
 	struct sockaddr_storage to;
@@ -1409,8 +1413,8 @@ xfrd_send_udp(acl_options_t* acl, buffer_type* packet, acl_options_t* ifc)
 }
 
 int
-xfrd_bind_local_interface(int sockd, acl_options_t* ifc, acl_options_t* acl,
-	int tcp)
+xfrd_bind_local_interface(int sockd, struct acl_options* ifc,
+	struct acl_options* acl, int tcp)
 {
 #ifdef SO_LINGER
 	struct linger linger = {1, 0};
@@ -1487,7 +1491,7 @@ xfrd_bind_local_interface(int sockd, acl_options_t* ifc, acl_options_t* acl,
 
 void
 xfrd_tsig_sign_request(buffer_type* packet, tsig_record_type* tsig,
-	acl_options_t* acl)
+	struct acl_options* acl)
 {
 	tsig_algorithm_type* algo;
 	assert(acl->key_options && acl->key_options->tsig_key);
@@ -1511,7 +1515,7 @@ xfrd_tsig_sign_request(buffer_type* packet, tsig_record_type* tsig,
 }
 
 static int
-xfrd_send_ixfr_request_udp(xfrd_zone_t* zone)
+xfrd_send_ixfr_request_udp(xfrd_zone_type* zone)
 {
 	int fd;
 
@@ -1553,7 +1557,7 @@ xfrd_send_ixfr_request_udp(xfrd_zone_t* zone)
 	return fd;
 }
 
-static int xfrd_parse_soa_info(buffer_type* packet, xfrd_soa_t* soa)
+static int xfrd_parse_soa_info(buffer_type* packet, xfrd_soa_type* soa)
 {
 	if(!buffer_available(packet, 10))
 		return 0;
@@ -1590,8 +1594,8 @@ static int xfrd_parse_soa_info(buffer_type* packet, xfrd_soa_t* soa)
  * (soa contents is modified by the routine)
  */
 static int
-xfrd_xfr_check_rrs(xfrd_zone_t* zone, buffer_type* packet, size_t count,
-	int *done, xfrd_soa_t* soa, region_type* temp)
+xfrd_xfr_check_rrs(xfrd_zone_type* zone, buffer_type* packet, size_t count,
+	int *done, xfrd_soa_type* soa, region_type* temp)
 {
 	/* first RR has already been checked */
 	uint32_t tmp_serial = 0;
@@ -1697,7 +1701,7 @@ xfrd_xfr_check_rrs(xfrd_zone_t* zone, buffer_type* packet, size_t count,
 }
 
 static int
-xfrd_xfr_process_tsig(xfrd_zone_t* zone, buffer_type* packet)
+xfrd_xfr_process_tsig(xfrd_zone_type* zone, buffer_type* packet)
 {
 	int have_tsig = 0;
 	assert(zone && zone->master && zone->master->key_options
@@ -1753,8 +1757,8 @@ xfrd_xfr_process_tsig(xfrd_zone_t* zone, buffer_type* packet)
 
 /* parse the received packet. returns xfrd packet result code. */
 static enum xfrd_packet_result
-xfrd_parse_received_xfr_packet(xfrd_zone_t* zone, buffer_type* packet,
-	xfrd_soa_t* soa)
+xfrd_parse_received_xfr_packet(xfrd_zone_type* zone, buffer_type* packet,
+	xfrd_soa_type* soa)
 {
 	size_t rr_count;
 	size_t qdcount = QDCOUNT(packet);
@@ -1888,13 +1892,13 @@ xfrd_parse_received_xfr_packet(xfrd_zone_t* zone, buffer_type* packet,
 			zone->soa_disk_acquired = xfrd_time();
 			if(zone->soa_nsd.serial == soa->serial)
 				zone->soa_nsd_acquired = xfrd_time();
+			xfrd_set_zone_state(zone, xfrd_zone_ok);
+ 			DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd: zone %s is ok",
+				zone->apex_str));
 			if(zone->zone_options->pattern->multi_master_check) {
 				region_destroy(tempregion);
 				return xfrd_packet_drop;
 			}
-			xfrd_set_zone_state(zone, xfrd_zone_ok);
- 			DEBUG(DEBUG_XFRD,1, (LOG_INFO, "xfrd: zone %s is ok",
-				zone->apex_str));
 			if(zone->soa_notified_acquired == 0) {
 				/* not notified or anything, so stop asking around */
 				zone->round_num = -1; /* next try start a new round */
@@ -1981,9 +1985,9 @@ xfrd_pretty_time(time_t v)
 }
 
 enum xfrd_packet_result
-xfrd_handle_received_xfr_packet(xfrd_zone_t* zone, buffer_type* packet)
+xfrd_handle_received_xfr_packet(xfrd_zone_type* zone, buffer_type* packet)
 {
-	xfrd_soa_t soa;
+	xfrd_soa_type soa;
 	enum xfrd_packet_result res;
         uint64_t xfrfile_size;
 
@@ -2168,7 +2172,7 @@ xfrd_handle_reload(int ATTR_UNUSED(fd), short event, void* ATTR_UNUSED(arg))
 }
 
 void
-xfrd_handle_notify_and_start_xfr(xfrd_zone_t* zone, xfrd_soa_t* soa)
+xfrd_handle_notify_and_start_xfr(xfrd_zone_type* zone, xfrd_soa_type* soa)
 {
 	if(xfrd_handle_incoming_notify(zone, soa)) {
 		if(zone->zone_handler.ev_fd == -1 && zone->tcp_conn == -1 &&
@@ -2191,7 +2195,7 @@ xfrd_handle_passed_packet(buffer_type* packet,
 	uint16_t qtype, qclass;
 	const dname_type* dname;
 	region_type* tempregion = region_create(xalloc, free);
-	xfrd_zone_t* zone;
+	xfrd_zone_type* zone;
 
 	buffer_skip(packet, QHEADERSZ);
 	if(!packet_read_query_section(packet, qnamebuf, &qtype, &qclass)) {
@@ -2204,7 +2208,7 @@ xfrd_handle_passed_packet(buffer_type* packet,
 		   "%d", dname_to_string(dname,0), acl_num));
 
 	/* find the zone */
-	zone = (xfrd_zone_t*)rbtree_search(xfrd->zones, dname);
+	zone = (xfrd_zone_type*)rbtree_search(xfrd->zones, dname);
 	if(!zone) {
 		/* this could be because the zone has been deleted meanwhile */
 		DEBUG(DEBUG_XFRD, 1, (LOG_INFO, "xfrd: incoming packet for "
@@ -2216,7 +2220,7 @@ xfrd_handle_passed_packet(buffer_type* packet,
 
 	/* handle */
 	if(OPCODE(packet) == OPCODE_NOTIFY) {
-		xfrd_soa_t soa;
+		xfrd_soa_type soa;
 		int have_soa = 0;
 		int next;
 		/* get serial from a SOA */
@@ -2244,7 +2248,7 @@ xfrd_handle_passed_packet(buffer_type* packet,
 }
 
 static int
-xfrd_handle_incoming_notify(xfrd_zone_t* zone, xfrd_soa_t* soa)
+xfrd_handle_incoming_notify(xfrd_zone_type* zone, xfrd_soa_type* soa)
 {
 	if(soa && zone->soa_disk_acquired && zone->state != xfrd_zone_expired &&
 	   compare_serial(ntohl(soa->serial),ntohl(zone->soa_disk.serial)) <= 0)
@@ -2277,12 +2281,12 @@ xfrd_handle_incoming_notify(xfrd_zone_t* zone, xfrd_soa_t* soa)
 }
 
 static int
-find_same_master_notify(xfrd_zone_t* zone, int acl_num_nfy)
+find_same_master_notify(xfrd_zone_type* zone, int acl_num_nfy)
 {
-	acl_options_t* nfy_acl = acl_find_num(zone->zone_options->pattern->
+	struct acl_options* nfy_acl = acl_find_num(zone->zone_options->pattern->
 		allow_notify, acl_num_nfy);
 	int num = 0;
-	acl_options_t* master = zone->zone_options->pattern->request_xfr;
+	struct acl_options* master = zone->zone_options->pattern->request_xfr;
 	if(!nfy_acl)
 		return -1;
 	while(master)
@@ -2299,8 +2303,8 @@ void
 xfrd_check_failed_updates()
 {
 	/* see if updates have not come through */
-	xfrd_zone_t* zone;
-	RBTREE_FOR(zone, xfrd_zone_t*, xfrd->zones)
+	xfrd_zone_type* zone;
+	RBTREE_FOR(zone, xfrd_zone_type*, xfrd->zones)
 	{
 		/* zone has a disk soa, and no nsd soa or a different nsd soa */
 		if(zone->soa_disk_acquired != 0 &&
@@ -2312,7 +2316,7 @@ xfrd_check_failed_updates()
 			{
 				/* this zone should have been loaded, since its disk
 				   soa time is before the time of the reload cmd. */
-				xfrd_soa_t dumped_soa = zone->soa_disk;
+				xfrd_soa_type dumped_soa = zone->soa_disk;
 				log_msg(LOG_ERR, "xfrd: zone %s: soa serial %u "
 						 		 "update failed, restarting "
 						 		 "transfer (notified zone)",
@@ -2351,8 +2355,8 @@ xfrd_check_failed_updates()
 void
 xfrd_prepare_zones_for_reload()
 {
-	xfrd_zone_t* zone;
-	RBTREE_FOR(zone, xfrd_zone_t*, xfrd->zones)
+	xfrd_zone_type* zone;
+	RBTREE_FOR(zone, xfrd_zone_type*, xfrd->zones)
 	{
 		/* zone has a disk soa, and no nsd soa or a different nsd soa */
 		if(zone->soa_disk_acquired != 0 &&
@@ -2380,10 +2384,10 @@ xfrd_get_temp_buffer()
 #ifdef BIND8_STATS
 /** process stat info task */
 static void
-xfrd_process_stat_info_task(xfrd_state_t* xfrd, struct task_list_d* task)
+xfrd_process_stat_info_task(xfrd_state_type* xfrd, struct task_list_d* task)
 {
 	size_t i;
-	stc_t* p = (void*)task->zname + sizeof(struct nsdst);
+	stc_type* p = (void*)task->zname + sizeof(struct nsdst);
 	stats_add(&xfrd->nsd->st, (struct nsdst*)task->zname);
 	for(i=0; i<xfrd->nsd->child_count; i++) {
 		xfrd->nsd->children[i].query_count += *p++;
@@ -2398,7 +2402,7 @@ xfrd_process_stat_info_task(xfrd_state_t* xfrd, struct task_list_d* task)
 #ifdef USE_ZONE_STATS
 /** process zonestat inc task */
 static void
-xfrd_process_zonestat_inc_task(xfrd_state_t* xfrd, struct task_list_d* task)
+xfrd_process_zonestat_inc_task(xfrd_state_type* xfrd, struct task_list_d* task)
 {
 	xfrd->zonestat_safe = (unsigned)task->oldserial;
 	zonestat_remap(xfrd->nsd, 0, xfrd->zonestat_safe*sizeof(struct nsdst));
@@ -2409,7 +2413,7 @@ xfrd_process_zonestat_inc_task(xfrd_state_t* xfrd, struct task_list_d* task)
 #endif /* USE_ZONE_STATS */
 
 static void
-xfrd_handle_taskresult(xfrd_state_t* xfrd, struct task_list_d* task)
+xfrd_handle_taskresult(xfrd_state_type* xfrd, struct task_list_d* task)
 {
 #ifndef BIND8_STATS
 	(void)xfrd;
@@ -2434,7 +2438,7 @@ xfrd_handle_taskresult(xfrd_state_t* xfrd, struct task_list_d* task)
 	}
 }
 
-void xfrd_process_task_result(xfrd_state_t* xfrd, struct udb_base* taskudb)
+void xfrd_process_task_result(xfrd_state_type* xfrd, struct udb_base* taskudb)
 {
 	udb_ptr t;
 	/* remap it for usage */
@@ -2452,7 +2456,7 @@ void xfrd_process_task_result(xfrd_state_t* xfrd, struct udb_base* taskudb)
 	task_clear(taskudb);
 }
 
-void xfrd_set_reload_now(xfrd_state_t* xfrd)
+void xfrd_set_reload_now(xfrd_state_type* xfrd)
 {
 	xfrd->need_to_send_reload = 1;
 	if(!(xfrd->ipc_handler_flags&EV_WRITE)) {
