@@ -121,17 +121,18 @@ extern int yydebug;
     T_CDNSKEY = 331,
     T_OPENPGPKEY = 332,
     T_CSYNC = 333,
-    DOLLAR_TTL = 334,
-    DOLLAR_ORIGIN = 335,
-    NL = 336,
-    SP = 337,
-    STR = 338,
-    PREV = 339,
-    BITLAB = 340,
-    T_TTL = 341,
-    T_RRCLASS = 342,
-    URR = 343,
-    T_UTYPE = 344
+    T_AVC = 334,
+    DOLLAR_TTL = 335,
+    DOLLAR_ORIGIN = 336,
+    NL = 337,
+    SP = 338,
+    STR = 339,
+    PREV = 340,
+    BITLAB = 341,
+    T_TTL = 342,
+    T_RRCLASS = 343,
+    URR = 344,
+    T_UTYPE = 345
   };
 #endif
 /* Tokens.  */
@@ -211,17 +212,18 @@ extern int yydebug;
 #define T_CDNSKEY 331
 #define T_OPENPGPKEY 332
 #define T_CSYNC 333
-#define DOLLAR_TTL 334
-#define DOLLAR_ORIGIN 335
-#define NL 336
-#define SP 337
-#define STR 338
-#define PREV 339
-#define BITLAB 340
-#define T_TTL 341
-#define T_RRCLASS 342
-#define URR 343
-#define T_UTYPE 344
+#define T_AVC 334
+#define DOLLAR_TTL 335
+#define DOLLAR_ORIGIN 336
+#define NL 337
+#define SP 338
+#define STR 339
+#define PREV 340
+#define BITLAB 341
+#define T_TTL 342
+#define T_RRCLASS 343
+#define URR 344
+#define T_UTYPE 345
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -238,7 +240,7 @@ union YYSTYPE
 	uint16_t	  type;
 	uint16_t	 *unknown;
 
-#line 242 "zparser.h" /* yacc.c:1909  */
+#line 244 "zparser.h" /* yacc.c:1909  */
 };
 
 typedef union YYSTYPE YYSTYPE;
